@@ -5,12 +5,13 @@ from cryptomodel.readonly import SymbolRates
 from mongoengine import Q
 
 from cryptodataaccess.Memory import Memory
+from cryptodataaccess.Repository import Repository
 from cryptodataaccess.helpers import server_time_out_wrapper, do_connect
 
 DATE_FORMAT = "%Y-%m-%d"
 
 
-class RatesRepository:
+class RatesRepository(Repository):
 
     def __init__(self, rates_store):
         self.rates_store = rates_store
